@@ -3,7 +3,9 @@ import pytest
 @pytest.fixture(scope='session', params=['pyrsistent', 'pvectorc'])
 def pvector(request):
     m = pytest.importorskip(request.param)
-    return m._pvector
+    if request.param == 'pyrsistent':
+        return m._pvector
+    return m.pvector
 
 
 def test_literalish_works():
@@ -112,6 +114,19 @@ def test_insert_beyond_end(pvector):
         seq2.assoc(19, 4)
 
 
+def test_insert_with_index_from_the_end(pvector):
+    x = pvector([1, 2, 3, 4])
+
+    assert x.assoc(-2, 5) == pvector([1, 2, 5, 4])
+
+
+def test_insert_with_too_negative_index(pvector):
+    x = pvector([1, 2, 3, 4])
+
+    with pytest.raises(IndexError):
+        x.assoc(-5, 17)
+
+
 def test_iteration(pvector):
     y = 0
     seq = pvector(range(2000))
@@ -251,17 +266,16 @@ def test_access_with_negative_index(pvector):
 
 def test_index_error_positive(pvector):
     with pytest.raises(IndexError):
-        x = pvector([1, 2, 3])[3]
+        pvector([1, 2, 3])[3]
 
 
 def test_index_error_negative(pvector):
     with pytest.raises(IndexError):
-        x = pvector([1, 2, 3])[-4]
+        pvector([1, 2, 3])[-4]
 
 
 def test_is_sequence(pvector):
     from collections import Sequence
-    assert isinstance(list(), Sequence)
     assert isinstance(pvector(), Sequence)
 
 
@@ -290,10 +304,13 @@ def test_repr_when_contained_object_contains_reference_to_self(pvector):
 
 
 def test_is_hashable(pvector):
+    from collections import Hashable
     v = pvector([1, 2, 3])
     v2 = pvector([1, 2, 3])
 
     assert hash(v) == hash(v2)
+    assert isinstance(pvector(), Hashable)
+
 
 
 def test_refuses_to_hash_when_members_are_unhashable(pvector):
@@ -347,3 +364,89 @@ def test_repeat(pvector):
     assert 0 * v is pvector()
     assert 2 * pvector([1, 2]) == pvector([1, 2, 1, 2])
     assert -3 * pvector([1, 2]) is pvector()
+
+
+def test_assoc_zero_key_length(pvector):
+    x = pvector([1, 2])
+
+    assert x.assoc_in([], 3) is x
+
+
+def test_assoc_in_base_case(pvector):
+    x = pvector([1, 2])
+
+    assert x.assoc_in([1], 3) == pvector([1, 3])
+
+
+def test_assoc_in_nested_vectors(pvector):
+    x = pvector([1, 2, pvector([3, 4]), 5])
+
+    assert x.assoc_in([2, 0], 999) == pvector([1, 2, pvector([999, 4]), 5])
+
+
+def test_assoc_in_when_appending(pvector):
+    from pyrsistent import m
+    x = pvector([1, 2])
+
+    assert x.assoc_in([2, 'd'], 999) == pvector([1, 2, m(d=999)])
+
+
+def test_assoc_in_index_error_out_range(pvector):
+    x = pvector([1, 2, pvector([3, 4]), 5])
+
+    with pytest.raises(IndexError):
+        x.assoc_in([2, 10], 999)
+
+
+def test_assoc_in_index_error_wrong_type(pvector):
+    x = pvector([1, 2, pvector([3, 4]), 5])
+
+    with pytest.raises(TypeError):
+        x.assoc_in([2, 'foo'], 999)
+
+
+def test_assoc_in_non_assocable_type(pvector):
+    x = pvector([1, 2, 5])
+
+    with pytest.raises(AttributeError):
+        x.assoc_in([2, 3], 999)
+
+
+def test_reverse(pvector):
+    x = pvector([1, 2, 5])
+
+    assert list(reversed(x)) == [5, 2, 1]
+
+
+def test_contains(pvector):
+    x = pvector([1, 2, 5])
+
+    assert 2 in x
+    assert 3 not in x
+
+
+def test_index(pvector):
+    x = pvector([1, 2, 5])
+
+    assert x.index(5) == 2
+
+
+def test_index_not_found(pvector):
+    x = pvector([1, 2, 5])
+
+    with pytest.raises(ValueError):
+        x.index(7)
+
+
+def test_index_not_found_with_limits(pvector):
+    x = pvector([1, 2, 5, 1])
+
+    with pytest.raises(ValueError):
+        x.index(1, 1, 3)
+
+
+def test_count(pvector):
+    x = pvector([1, 2, 5, 1])
+
+    assert x.count(1) == 2
+    assert x.count(4) == 0
